Module reindex

Module reindex 

Incremental reindex orchestrator.

Ties together the manifest, object store, diff, and embedding pipeline to provide a single incremental_index function that loads cached embeddings and only re-embeds changed files.

Structs

ReindexStats
Statistics from an incremental reindex operation.

Functions

heal_manifest_mtimes
Update manifest file mtimes to match the current filesystem.
incremental_index
Load or incrementally update a persistent index.
is_repo_local
Check if the resolved cache directory is inside a .ripvec/ directory.
load_cached_index
Load a pre-built index from the disk cache without re-embedding.
resolve_cache_dir
Resolve the cache directory for a project + model combination.