Module store

Module store 

Content-addressed object store with git-style sharding.

Objects are stored at <root>/xx/yyyyyyyy... where xx is the first two hex chars of the blake3 hash and yyyy... is the remainder. This prevents too many files in a single directory.

Structs

ObjectStore
Content-addressed object store with git-style xx/hash sharding.