Incremental reindex orchestrator.
Ties together the manifest, object store, diff, and embedding pipeline
to provide a single incremental_index function that loads cached
embeddings and only re-embeds changed files.
Structs
- Reindex
Stats - Statistics from an incremental reindex operation.
Functions
- apply_
auto_ stash - Apply the user’s
auto_stashchoice: set git config and save toconfig.toml. - check_
auto_ stash - Check whether
pull.autoStashneeds to be configured for a repo-local cache. - heal_
manifest_ mtimes - Update manifest file mtimes to match the current filesystem.
- incremental_
index - Load or incrementally update a persistent index.
- is_
repo_ local - Check if the resolved cache directory is inside a
.ripvec/directory. - load_
cached_ index - Load a pre-built index from the disk cache without re-embedding.
- resolve_
cache_ dir - Resolve the cache directory for a project + model combination.