Module reindex

Module reindex 

Incremental reindex orchestrator.

Ties together the manifest, object store, diff, and embedding pipeline to provide a single incremental_index function that loads cached embeddings and only re-embeds changed files.

Structs

ReindexStats
Statistics from an incremental reindex operation.

Functions

incremental_index
Load or incrementally update a persistent index.
resolve_cache_dir
Resolve the cache directory for a project + model combination.