Module walk

Module walk 

Parallel directory traversal using the ignore crate.

Respects .gitignore rules, skips hidden files, and filters to files with supported source extensions. Uses build_parallel() for multi-threaded file discovery.

Functions

collect_files
Walk a directory tree in parallel and collect file paths.